@@ -458,7 +458,7 @@ If you think this report is invalid, please consult the CPAN Testers Wiki
 for suggestions on how to avoid getting FAIL reports for missing library
 or binary dependencies, unsupported operating systems, and so on:
 
-http://cpantest.grango.org/wiki/CPANAuthorNotes
+http://wiki.cpantesters.org/wiki/CPANAuthorNotes
 HERE
 
     'unknown' => << 'HERE',
@@ -470,7 +470,7 @@ stage, did not define tests, tests could not be found, because your tests were
 interrupted before they finished, or because the results of the tests could not
 be parsed.  You may wish to consult the CPAN Testers Wiki:
 
-http://cpantest.grango.org/wiki/CPANAuthorNotes
+http://wiki.cpantesters.org/wiki/CPANAuthorNotes
 HERE
 
     'na' => << 'HERE',
@@ -480,7 +480,7 @@ either for this operating system or this version of Perl.  Nevertheless, any
 diagnostic output produced is provided below for reference.  If this is not 
 what you expect, you may wish to consult the CPAN Testers Wiki:
 
-http://cpantest.grango.org/wiki/CPANAuthorNotes
+http://wiki.cpantesters.org/wiki/CPANAuthorNotes
 HERE
     
 );
@@ -786,7 +786,16 @@ sub transport {
     }
     return $mocked_data{transport};
 }
-    
+  
+# must do this one manually so ->can('distfile') is true
+sub distfile {
+  my $self = shift;
+  if ( @_ ) {
+    $mocked_data{ distfile } = shift;
+  }
+  return $mocked_data{ distfile };
+}
+
 sub AUTOLOAD {
     my $self = shift;
     if ( @_ ) {
